### Code for generating graphics ####

rm(list=ls(all=TRUE))
setwd("/Users/jalo/Dropbox/texas")


### Produces the graph of the individual shifts (All Texas Legislators)
load("result.rda")
legis.pre <- result$legislators[shifted,]
legis.post <- result$legislators[paste(shifted,".post",sep=""),]

ordering <- order(legis.pre$coord1D)
legis.pre <- legis.pre[ordering,]
legis.post <- legis.post[ordering,]

namelist <- c("Jackson-Lee (D TX-18)",  "Doggett (D TX-10)",  "Johnson (D TX-30)",  "Rodriguez (D TX-28)",
 "Frost (D TX-24)",  "Gonzalez (D TX-20)", "Lampson (D TX-9)",  "Bell (D TX-25)",      
"Green (D TX-29)", "Sandlin (D TX-1)", "Reyes (D TX-16)",  "Hinojosa (D TX-15)",  
"Ortiz (D TX-27)", "Edwards (D TX-11)", "Turner (D TX-2)", "Stenholm (D TX-17)",  
"Granger (R TX-12)", "Bonilla (R TX-23)", "Smith (R TX-21)", "Paul (R TX-14)",  
"Thornberry(R TX-13)", "DeLay (R TX-22)", "Carter (R TX-31)", "Hensarling (R TX-5)",  
"Brady (R TX-8)", "Barton (R TX-6)", "Neugebauer (R TX-19)", "Burgess (R TX-26)",   
"Sessions (R TX-32)", "Johnson (R TX-3)", "Culberson (R TX-7)")

targetvec <- c(2, 5, 7, 8, 10, 14, 15, 16)
othervec <- (1:nrow(legis.pre))[-targetvec]

postscript("shifts.eps")
par(mar=c(5.1,7.5, 0, 2.1),yaxt="n")
offset=0.12
plot(legis.pre$coord1D,1:nrow(legis.pre), type="n", xlim=c(-1,1),yaxt="n",bty="n",
	ylim=c(0.8,nrow(legis.pre)),xlab="NOMINATE score",ylab="",cex.lab=1.2)
for(i in 1:nrow(legis.pre)){
    segments(legis.pre$coord1D[i] - 1.96*legis.pre$se1D[i], i-offset,
		legis.pre$coord1D[i] + 1.96*legis.pre$se1D[i],col="grey")
    segments(legis.post$coord1D[i] - 1.96*legis.post$se1D[i], i+offset,
		legis.post$coord1D[i] + 1.96*legis.post$se1D[i],col="grey")

}
points(legis.pre$coord1D,(1:nrow(legis.pre))-offset,pch=20,cex=0.6)
points(legis.post$coord1D,(1:nrow(legis.post))+offset,pch=15,cex=0.6)

mtext(namelist[targetvec], side=2, at=(1:nrow(legis.pre))[targetvec],las=1,adj=1,cex=0.7, font=4)
mtext(namelist[othervec], side=2, at=(1:nrow(legis.pre))[othervec],las=1,adj=1,cex=0.6)
dev.off()



### Looking at the magnitude of the estimate result
load("result.rda")
result$legislators$coord1D
selector.dem <- grep("\\(D ",rownames(result$legislators))
selector.dem <- selector.dem[1:(length(selector.dem)-16)]	#Don't double-count the Texas Demcrats
rownames(result$legislators)[selector.dem]			#Democrats only
sd(result$legislators$coord1D[selector.dem]) 			#0.1825307, Dem caucus only
sd(result$legislators$coord1D[1:(length(result$legislators$coord1D)-31)]) # 0.5949681, full Congress
-0.0152 - 1.96*0.01963309		#Lower 95% CI
-0.0152 + 1.96*0.01963309		#Upper 95% CI



if(0){ 

### Produces the graph of the individual shifts (Targeted Democrats Only)
### Graphic appeared in original version of graphic submitted to QJPS, not used
load("result.rda")
shifted <- rev(c("SANDLIN (D TX-1)","TURNER (D TX-2)","LAMPSON (D TX-9)",
"DOGGETT (D TX-10)","EDWARDS (D TX-11)","STENHOLM (D TX-17)","FROST (D TX-24)",
"BELL (D TX-25)"))
legis.pre <- result$legislators[shifted,]
legis.post <- result$legislators[paste(shifted,".post",sep=""),]
namelist <- rev(c("Sandlin (TX-1)","Turner (TX-2)","Lampson (TX-9)",
"Doggett (TX-10)","Edwards (TX-11)","Stenholm (TX-17)","Frost (TX-24)",
"Bell (TX-25)"))

#pdf("shifts.pdf")
par(mar=c(5.1,7.5, 0, 2.1),yaxt="n")
offset=0.1
plot(legis.pre$coord1D,1:nrow(legis.pre), type="n", xlim=c(-1,0),yaxt="n",bty="n",
	ylim=c(0.8,nrow(legis.pre)),xlab="NOMINATE score",ylab="",cex.lab=1.2)
for(i in 1:nrow(legis.pre)){
    segments(legis.pre$coord1D[i] - 1.96*legis.pre$se1D[i], i-offset,
		legis.pre$coord1D[i] + 1.96*legis.pre$se1D[i],col="grey")
    segments(legis.post$coord1D[i] - 1.96*legis.post$se1D[i], i+offset,
		legis.post$coord1D[i] + 1.96*legis.post$se1D[i],col="grey")

}
points(legis.pre$coord1D,(1:nrow(legis.pre))-offset,pch=20)
points(legis.post$coord1D,(1:nrow(legis.post))+offset,pch=15)

mtext(namelist, side=2, at=1:nrow(legis.pre),las=1,adj=1,cex=0.9)
segments(-1.5,seq(1.5,15.5),1,lty=3,col="grey")
#dev.off()
}


### HISTOGRAMS OF FALSIFICATION TEST (RANDOMIZED VOTES) ###
rm(list=ls(all=TRUE))
load("falsification.rda")

postscript("falsification.eps")
shift <- -0.015
shift_post <- apply(results[targets,],2,mean)
hist(shift_post,breaks=20,xlim=c(-0.1,0.10),ylim=c(0,25),main=NA,xlab=NA,ylab=NA,col="grey",freq=FALSE)
mtext("Shift in Nominate Score", side=1, cex=1.2,line=2.5) 
mtext("Density", side=2, cex=1.2,line=2.5) 
text( shift,24.5,"Observed\n shift",cex=1.2,font=3)
arrows( shift,23, shift,20,length=0.15,angle=20)
dev.off()


### HISTOGRAMS OF BOOTSTRAP TEST (RANDOMIZED LEGISLATORS) ###
rm(list=ls(all=TRUE))
load("bootstrap.rda")

postscript("bootstrap.eps")
shift <- -0.015
shift_post <- apply(results[1:8,],2,mean,na.rm=TRUE)
hist(shift_post,breaks=20,xlim=c(-0.10,0.10),ylim=c(0,25),main=NA,xlab=NA,ylab=NA,col="grey",freq=FALSE)
mtext("Shift in Nominate Score", side=1, cex=1.2,line=2.5) 
mtext("Density", side=2, cex=1.2,line=2.5) 
text( shift,24.5,"Observed\n shift",cex=1.2,font=3)
arrows( shift,23, shift,20,length=0.15,angle=20)
dev.off()

