##############
### REPLICATION CODE FOR: ``Legislative Responsiveness to Gerrymandering: Evidence from the 2003 Texas Redistricting''
### Notes:	Data sets are not necessary because they can all be FTP'd from Keith Poole's Voteview website
###		Each piece of the analysis is separated with a full wipe of contents and a new setwd, so each piece can be run individually
###		Estimation of the bootstrap trials can take a LONG time --- I recommend setting the `trials' parameter lower for test runs
###		Nevertheless, the SEs in the paper are derived from longer trials, so the code is retained as used for the paper 
##############

rm(list=ls(all=TRUE))
setwd("/Users/jalo/Dropbox/texas")
library(wnominate)

h108 <- readKH("ftp://voteview.com/hou108kh.ord")

###### MAIN RESULT ######

shifted <- c("SANDLIN (D TX-1)", "TURNER (D TX-2)", "JOHNSON (R TX-3)", "HENSARLIN (R TX-5)", "BARTON (R TX-6)",
"CULBERSO (R TX-7)", "BRADY (R TX-8)", "LAMPSON (D TX-9)", "DOGGETT (D TX-10)", "EDWARDS (D TX-11)",
"GRANGER (R TX-12)", "THORNBER (R TX-13)", "PAUL (R TX-14)", "HINOJOSA (D TX-15)", "REYES (D TX-16)",    
"STENHOLM (D TX-17)", "JACKSON- (D TX-18)", "NEUGEBAUER (R TX-19)",
"GONZALEZ (D TX-20)", "SMITH (R TX-21)", "DELAY (R TX-22)", "BONILLA (R TX-23)",
"FROST (D TX-24)", "BELL (D TX-25)", "BURGESS (R TX-26)", "ORTIZ (D TX-27)",
"RODRIGUE (D TX-28)", "GREEN (D TX-29)", "JOHNSON (D TX-30)", "CARTER (R TX-31)","SESSIONS (R TX-32)")

targets <- c("SANDLIN (D TX-1)","TURNER (D TX-2)","LAMPSON (D TX-9)",
"DOGGETT (D TX-10)","EDWARDS (D TX-11)","STENHOLM (D TX-17)","FROST (D TX-24)",
"BELL (D TX-25)")

others <- shifted[!(shifted %in% targets)]
others.rep <- others[grep("R ",others)]
others.dem <- others[grep("D ",others)]

cutoff <- 461	#This is first vote after Sept. 3,2003
vote108 <- h108$votes
post <- vote108[shifted,]
rownames(post) <- paste(rownames(post),".post",sep="")
post[,1:(cutoff-1)] <- 9
vote108[shifted,cutoff:ncol(vote108)] <- 9
vote108 <- rbind(vote108,post)
dat <- rollcall(vote108, yea=1:3,nay=4:6,missing=7:9,notInLegis=0,legis.names=rownames(vote108))

### This estimated result is used to generate Figure 1
result <- wnominate(dat,dims=1,polarity=1,trials=10)

changes <- matrix(NA,nrow=length(shifted),ncol=2)
rownames(changes) <- shifted
changes[,1] <- result$legislators[shifted,"coord1D"]
changes[,2] <- result$legislators[paste(shifted,".post",sep=""),"coord1D"]
changes[,2]-changes[,1]

mean(changes[targets,2]-changes[targets,1])	#-0.01523426, the main estimated result in Table 1
max(changes[,2]-changes[,1],na.rm=TRUE)		#0.1914198 Hensarling, reported in FN 11
mean(changes[others.rep,2]-changes[others.rep,1])	#0.01415201, shift for Texas Republicans in Table 1
mean(changes[others.dem,2]-changes[others.dem,1])	#-0.01252478, shift for other Texas Democrats in Table 1

##### Robustness check 1: Cutoff at proposal ##### 
cutoff <- 182
vote108 <- h108$votes
post <- vote108[shifted,]
rownames(post) <- paste(rownames(post),".post",sep="")
post[,1:(cutoff-1)] <- 9
vote108[shifted,cutoff:ncol(vote108)] <- 9
vote108 <- rbind(vote108,post)
dat <- rollcall(vote108, yea=1:3,nay=4:6,missing=7:9,notInLegis=0,legis.names=rownames(vote108))

result.afterproposal <- wnominate(dat,dims=1,polarity=1,trials=1)

changes <- matrix(NA,nrow=length(shifted),ncol=2)
rownames(changes) <- shifted
changes[,1] <- result.afterproposal$legislators[shifted,"coord1D"]
changes[,2] <- result.afterproposal$legislators[paste(shifted,".post",sep=""),"coord1D"]
changes[,2]-changes[,1]

### This is the result reported as "Treatment begins after legislation introduced" in Table 1
mean(changes[targets,2]-changes[targets,1])	#-0.04534602


##### Robustness check 2: Cutoff after court ruling ##### 

cutoff <- 676		# January 6, 2004
vote108 <- h108$votes
post <- vote108[shifted,]
rownames(post) <- paste(rownames(post),".post",sep="")
post[,1:(cutoff-1)] <- 9
vote108[shifted,cutoff:ncol(vote108)] <- 9
vote108 <- rbind(vote108,post)
dat <- rollcall(vote108, yea=1:3,nay=4:6,missing=7:9,notInLegis=0,legis.names=rownames(vote108))

result.aftercourt <- wnominate(dat,dims=1,polarity=1,trials=1)

changes <- matrix(NA,nrow=length(shifted),ncol=2)
rownames(changes) <- shifted
changes[,1] <- result.aftercourt$legislators[shifted,"coord1D"]
changes[,2] <- result.aftercourt$legislators[paste(shifted,".post",sep=""),"coord1D"]
changes[,2]-changes[,1]

### This is the result reported as "Treatment begins after legislation survives legal challenges" in Table 1
mean(changes[targets,2]-changes[targets,1])	#0.01309578

save(shifted, targets, result, result.afterproposal, result.aftercourt, file="result.rda")



###### THE NEXT SECTION IS RESAMPLING DONE FOR STANDARD ERROR SIMULATIONS ######
###### REPORTED RESULTS ARE DONE WITH LARGE NUMBER OF SIMULATIONS SHOWN AND SAVED ####
###### UNLESS

###### BOOTSTRAP RESULT ######
rm(list=ls(all=TRUE))
#setwd("/Users/jalo/Dropbox/texas")
library(wnominate)

h108 <- readKH("ftp://voteview.com/hou108kh.ord")

bigvotes <- h108$votes
set.seed(300)
trials <- 1000
results <- matrix(NA,nrow=31,ncol=trials)
cutoff <- 461	#This is first vote after Sept. 3,2003

for(i in 1:trials){

vote108 <- bigvotes			# Overwrite copy each time
eligible <- c(2:371, 406:nrow(vote108))	# Dump Bush and all Texas legislators from placebo sample
shifted <- rownames(vote108)[sample(eligible,31)]

post <- vote108[shifted,]
rownames(post) <- paste(rownames(post),".post",sep="")
post[,1:(cutoff-1)] <- 9
vote108[shifted,cutoff:ncol(vote108)] <- 9
vote108 <- rbind(vote108,post)
dat <- rollcall(vote108, yea=1:3,nay=4:6,missing=7:9,notInLegis=0,legis.names=rownames(vote108))
result <- wnominate(dat,dims=1,polarity=1)
changes <- matrix(NA,nrow=length(shifted),ncol=2)
rownames(changes) <- shifted
changes[,1] <- result$legislators[shifted,"coord1D"]
changes[,2] <- result$legislators[paste(shifted,".post",sep=""),"coord1D"]
results[,i] <- (changes[,2]-changes[,1])

} #end for
save(results,file="bootstrap.rda")

## This is the Standard Error for Control Units under no treatment condition
## reported on first paragraph of pg. 11. This sampling distribution for this
## is later used to plot the left panel, "Randomized Legislators", of Figure 2
## sd(apply(results[1:8,],2,mean,na.rm=TRUE))	# 0.02091367


#### RESAMPLING: ALLOW EVERYONE TO MOVE ####

rm(list=ls(all=TRUE))
library(wnominate)
set.seed(300)

shifted <- c("SANDLIN (D TX-1)", "TURNER (D TX-2)", "JOHNSON (R TX-3)", "HENSARLIN (R TX-5)", "BARTON (R TX-6)",
"CULBERSO (R TX-7)", "BRADY (R TX-8)", "LAMPSON (D TX-9)", "DOGGETT (D TX-10)", "EDWARDS (D TX-11)",
"GRANGER (R TX-12)", "THORNBER (R TX-13)", "PAUL (R TX-14)", "HINOJOSA (D TX-15)", "REYES (D TX-16)",    
"STENHOLM (D TX-17)", "JACKSON- (D TX-18)", "NEUGEBAUER (R TX-19)",
"GONZALEZ (D TX-20)", "SMITH (R TX-21)", "DELAY (R TX-22)", "BONILLA (R TX-23)",
"FROST (D TX-24)", "BELL (D TX-25)", "BURGESS (R TX-26)", "ORTIZ (D TX-27)",
"RODRIGUE (D TX-28)", "GREEN (D TX-29)", "JOHNSON (D TX-30)", "CARTER (R TX-31)","SESSIONS (R TX-32)")

targets <- c("SANDLIN (D TX-1)","TURNER (D TX-2)","LAMPSON (D TX-9)",
"DOGGETT (D TX-10)","EDWARDS (D TX-11)","STENHOLM (D TX-17)","FROST (D TX-24)",
"BELL (D TX-25)")

others <- shifted[!(shifted %in% targets)]
others.rep <- others[grep("R ",others)]
others.dem <- others[grep("D ",others)]

fulldata <- readKH("ftp://voteview.com/hou108kh.ord")
trials <- 1000
results <- matrix(NA,nrow=length(shifted),ncol=trials)
rownames(results) <- shifted
cutoff <- 461	#This is first vote after Sept. 3,2003

for(i in 1:trials){

# Conduct randomization
h108 <- fulldata
h108$votes <- h108$votes[,sample(1:ncol(h108$votes),ncol(h108$votes))]

vote108 <- h108$votes
post <- vote108[shifted,]
rownames(post) <- paste(rownames(post),".post",sep="")
post[,1:(cutoff-1)] <- 9
vote108[shifted,cutoff:ncol(vote108)] <- 9
vote108 <- rbind(vote108,post)
dat <- rollcall(vote108, yea=1:3,nay=4:6,missing=7:9,notInLegis=0,legis.names=rownames(vote108))

result <- wnominate(dat,dims=1,polarity=1)

changes <- matrix(NA,nrow=length(shifted),ncol=2)
rownames(changes) <- shifted
changes[,1] <- result$legislators[shifted,"coord1D"]
changes[,2] <- result$legislators[paste(shifted,".post",sep=""),"coord1D"]
results[,i] <- (changes[,2]-changes[,1])

} #end for
save(results,shifted,others,others.rep,others.dem,targets,file="falsification.rda")

## This is the Standard Error for Treatment Units under no treatment condition
## reported on second paragraph of pg. 11, and Table 1. This sampling distribution for this
## is later used to plot the right panel, "Randomized Votes", of Figure 2
## sd(apply(results[1:8,],2,mean,na.rm=TRUE))	# 0.02091367

sd(apply(results[targets,],2,mean))	#0.01963309, SE for Main Result, Table 1
sd(apply(results[others.rep,],2,mean))	#0.01834279, SE for Texas Republicans, Table 1
sd(apply(results[others.dem,],2,mean))	#0.02061541, SE for Texas Democrats, Table 1




### RESAMPLING TEST FOR STANDARD ERRORS: ASSUME TREATMENT AFTER LEGISLATION INTRODUCED
rm(list=ls(all=TRUE))
library(wnominate)
set.seed(300)

shifted <- c("SANDLIN (D TX-1)", "TURNER (D TX-2)", "JOHNSON (R TX-3)", "HENSARLIN (R TX-5)", "BARTON (R TX-6)",
"CULBERSO (R TX-7)", "BRADY (R TX-8)", "LAMPSON (D TX-9)", "DOGGETT (D TX-10)", "EDWARDS (D TX-11)",
"GRANGER (R TX-12)", "THORNBER (R TX-13)", "PAUL (R TX-14)", "HINOJOSA (D TX-15)", "REYES (D TX-16)",    
"STENHOLM (D TX-17)", "JACKSON- (D TX-18)", "NEUGEBAUER (R TX-19)",
"GONZALEZ (D TX-20)", "SMITH (R TX-21)", "DELAY (R TX-22)", "BONILLA (R TX-23)",
"FROST (D TX-24)", "BELL (D TX-25)", "BURGESS (R TX-26)", "ORTIZ (D TX-27)",
"RODRIGUE (D TX-28)", "GREEN (D TX-29)", "JOHNSON (D TX-30)", "CARTER (R TX-31)","SESSIONS (R TX-32)")

targets <- c("SANDLIN (D TX-1)","TURNER (D TX-2)","LAMPSON (D TX-9)",
"DOGGETT (D TX-10)","EDWARDS (D TX-11)","STENHOLM (D TX-17)","FROST (D TX-24)",
"BELL (D TX-25)")


fulldata <- readKH("ftp://voteview.com/hou108kh.ord")
trials <- 10
results <- matrix(NA,nrow=length(shifted),ncol=trials)
rownames(results) <- shifted
cutoff <- 182

for(i in 1:trials){

# Conduct randomization
h108 <- fulldata
h108$votes <- h108$votes[,sample(1:ncol(h108$votes),ncol(h108$votes))]

vote108 <- h108$votes
post <- vote108[shifted,]
rownames(post) <- paste(rownames(post),".post",sep="")
post[,1:(cutoff-1)] <- 9
vote108[shifted,cutoff:ncol(vote108)] <- 9
vote108 <- rbind(vote108,post)
dat <- rollcall(vote108, yea=1:3,nay=4:6,missing=7:9,notInLegis=0,legis.names=rownames(vote108))

result <- wnominate(dat,dims=1,polarity=1)

changes <- matrix(NA,nrow=length(shifted),ncol=2)
rownames(changes) <- shifted
changes[,1] <- result$legislators[shifted,"coord1D"]
changes[,2] <- result$legislators[paste(shifted,".post",sep=""),"coord1D"]
results[,i] <- (changes[,2]-changes[,1])

} #end for
save(results,shifted,targets,file="falsification_afterproposal.rda")

sd(apply(results[targets,],2,mean))	#0.02922123, SE for "Treatment begins after legislation introduced", Table 1




### RESAMPLING TEST FOR STANDARD ERRORS: ASSUME TREATMENT AFTER LEGISLATION SURVIVES COURT CHALLENGE

rm(list=ls(all=TRUE))
library(wnominate)
set.seed(300)

shifted <- c("SANDLIN (D TX-1)", "TURNER (D TX-2)", "JOHNSON (R TX-3)", "HENSARLIN (R TX-5)", "BARTON (R TX-6)",
"CULBERSO (R TX-7)", "BRADY (R TX-8)", "LAMPSON (D TX-9)", "DOGGETT (D TX-10)", "EDWARDS (D TX-11)",
"GRANGER (R TX-12)", "THORNBER (R TX-13)", "PAUL (R TX-14)", "HINOJOSA (D TX-15)", "REYES (D TX-16)",    
"STENHOLM (D TX-17)", "JACKSON- (D TX-18)", "NEUGEBAUER (R TX-19)",
"GONZALEZ (D TX-20)", "SMITH (R TX-21)", "DELAY (R TX-22)", "BONILLA (R TX-23)",
"FROST (D TX-24)", "BELL (D TX-25)", "BURGESS (R TX-26)", "ORTIZ (D TX-27)",
"RODRIGUE (D TX-28)", "GREEN (D TX-29)", "JOHNSON (D TX-30)", "CARTER (R TX-31)","SESSIONS (R TX-32)")

targets <- c("SANDLIN (D TX-1)","TURNER (D TX-2)","LAMPSON (D TX-9)",
"DOGGETT (D TX-10)","EDWARDS (D TX-11)","STENHOLM (D TX-17)","FROST (D TX-24)",
"BELL (D TX-25)")

fulldata <- readKH("ftp://voteview.com/hou108kh.ord")
trials <- 10
results <- matrix(NA,nrow=length(shifted),ncol=trials)
rownames(results) <- shifted
cutoff <- 676	#This is first vote after Sept. 3,2003

for(i in 1:trials){

# Conduct randomization
h108 <- fulldata
h108$votes <- h108$votes[,sample(1:ncol(h108$votes),ncol(h108$votes))]

vote108 <- h108$votes
post <- vote108[shifted,]
rownames(post) <- paste(rownames(post),".post",sep="")
post[,1:(cutoff-1)] <- 9
vote108[shifted,cutoff:ncol(vote108)] <- 9
vote108 <- rbind(vote108,post)
dat <- rollcall(vote108, yea=1:3,nay=4:6,missing=7:9,notInLegis=0,legis.names=rownames(vote108))

result <- wnominate(dat,dims=1,polarity=1)

changes <- matrix(NA,nrow=length(shifted),ncol=2)
rownames(changes) <- shifted
changes[,1] <- result$legislators[shifted,"coord1D"]
changes[,2] <- result$legislators[paste(shifted,".post",sep=""),"coord1D"]
results[,i] <- (changes[,2]-changes[,1])

} #end for
save(results,shifted,targets,file="falsification_aftercourt.rda")

sd(apply(results[targets,],2,mean))	#0.01893792, SE for "Treatment begins after legislation survives legal challenges", Table 1




###### MODEL COMPARING 108th to 109th MERGED FOR DOGGETT AND EDWARDS #######

rm(list=ls(all=TRUE))
setwd("/Users/jameslo/Dropbox/texas")
library(wnominate)

### Read data
hou108 <- readKH("ftp://voteview.com/hou108kh.ord")
hou109 <- readKH("ftp://voteview.com/hou109kh.ord")
dat1 <- hou108$votes
dat2 <- hou109$votes

### Note that all of the names already line up, except for 3 legislators
### Neugebauer needs to be fixed
### Doggett and Edwards do not, already separated pre-post
rownames(dat1)[grep("TX",rownames(dat1))]
rownames(dat2)[grep("TX",rownames(dat2))]
rownames(dat2)[which(rownames(dat2)=="NEUGEBAUE (R TX-19)" )] <- "NEUGEBAUER (R TX-19)"

### Merged is a combined matrix of 108th and 109th legislature
merged <- merge(dat1,dat2,all=TRUE,by=0)
rownames(merged) <- merged$Row.names
merged$Row.names <- NULL
merged <- as.matrix(merged)
merged[is.na(merged)] <- 9
votes <- rollcall(merged, yea = 1:3, nay = 4:6, missing = 7:9, notInLegis = 0, legis.names = rownames(merged))

result <- wnominate(votes,dims=1,polarity=3,trials=10)

### Individual estimates for Doggett and Edwards, reported on pg. 13 as footnote 16.
result$legislators["DOGGETT (D TX-10)",]	# Before coord: -0.5873604
result$legislators["DOGGETT (D TX-25)",]	# After coord: -0.547178
result$legislators["EDWARDS (D TX-11)",]	# Before coord: -0.1904736
result$legislators["EDWARDS (D TX-17)",]	# After coord: -0.1659852

### Estimated mean shift for Doggett and Edwards of 0.32, reported on pg. 13
mean(c(result$legislators["DOGGETT (D TX-25)","coord1D"] - result$legislators["DOGGETT (D TX-10)","coord1D"],
result$legislators["EDWARDS (D TX-17)","coord1D"] - result$legislators["EDWARDS (D TX-11)","coord1D"]))

rm(merged,votes,dat1,dat2)

#### Placebo test for 108th-109th merge data set ####
## Takes random groups of 2 legislators to estimate standard errors ###
## 'result' above is saved below, but the only thing it's needed for is to estimate mean Doggett/Edwards shift, already done above

trials=100
samplingdist <- numeric(trials)

### Read data
hou108 <- readKH("ftp://voteview.com/hou108kh.ord")
hou109 <- readKH("ftp://voteview.com/hou109kh.ord")
dat1 <- hou108$votes
dat2 <- hou109$votes
rownames(dat2)[which(rownames(dat2)=="NEUGEBAUE (R TX-19)" )] <- "NEUGEBAUER (R TX-19)"

### Create list of placebos
placebos <- intersect(rownames(dat1),rownames(dat2))
placebos <- placebos[placebos!="BUSH (R USA)"]
length(placebos)
placebos <- placebos[-grep("TX",placebos)]


for(i in 1:trials){

## Determine and rename placebo treatment units in a copy of 109th house data
treatthese <- sample(placebos,2)
postdat <- dat2	#Need to copy this each time
rownames(postdat)[which(rownames(postdat)==treatthese[1])] <-paste(treatthese[1],".post",sep="")
rownames(postdat)[which(rownames(postdat)==treatthese[2])] <-paste(treatthese[2],".post",sep="")

### Conduct merging as before, but be careful about polarity
merged <- merge(dat1,postdat,all=TRUE,by=0)
rownames(merged) <- merged$Row.names
merged$Row.names <- NULL
merged <- as.matrix(merged)
merged[is.na(merged)] <- 9
votes <- rollcall(merged, yea = 1:3, nay = 4:6, missing = 7:9, notInLegis = 0, legis.names = rownames(merged))
pol <- which(rownames(merged)=="DELAY (R TX-22)")

result.placebo <- wnominate(votes,dims=1,polarity=pol,trials=1)
samplingdist[i] <- mean(result.placebo$legislators[paste(treatthese,".post",sep=""),"coord1D"] - result.placebo$legislators[treatthese,"coord1D"],na.rm=TRUE)

rm(postdat,merged,pol,votes,result.placebo)

#result$legislators[paste(treatthese,".post",sep=""),"coord1D"] 
#result$legislators[treatthese,"coord1D"]

} #end for()

save(samplingdist, result,file="acrosslegis.rda")

sd(samplingdist)  #0.04980141, reported as standard error of estimate for Doggett/Edwards estimate

### Estimated mean shift for Dogget and Edwards of 0.32, reported on pg. 13. Identical to above.
mean(c(result$legislators["DOGGETT (D TX-25)","coord1D"] - result$legislators["DOGGETT (D TX-10)","coord1D"],
result$legislators["EDWARDS (D TX-17)","coord1D"] - result$legislators["EDWARDS (D TX-11)","coord1D"]))
